@@ -14,11 +14,10 @@ import time
 import warnings
 import click
 import inspect
-import get 
-import write 
-import config 
-import parse
-import logs
+from alacorder import get
+from alacorder import parse
+from alacorder import write
+from alacorder import config
 
 def echo_conf(input_path,make,output_path,overwrite,no_write,dedupe,launch,warn,no_prompt):
 	d = click.style(f"""\n* Successfully configured!\n""",fg='green', bold=True)
@@ -26,27 +25,13 @@ def echo_conf(input_path,make,output_path,overwrite,no_write,dedupe,launch,warn,
 	f = click.style(f"""{"OVERWRITE is enabled. Alacorder will overwrite existing files at output path! " if overwrite else ''}{"NO-WRITE is enabled. Alacorder will NOT export outputs. " if no_write else ''}{"REMOVE DUPLICATES is enabled. At time of export, all duplicate cases will be removed from output. " if dedupe else ''}{"LAUNCH is enabled. Upon completion, Alacorder will attempt to launch exported file in default viewing application. " if launch and make != "archive" else ''}{"WARN is enabled. All warnings from pandas and other modules will print to console. " if warn else ''}{"NO_PROMPT is enabled. All user confirmation prompts will be suppressed as if set to default by user." if no_prompt else ''}""".strip(), italic=True, fg='white')
 	return d + e + "\n" + f + "\n"
 
-def complete(conf, start_time, output=None):
-	path_in = conf['INPUT_PATH']
-	path_out = conf['OUTPUT_PATH']
-	arc_out = conf['OUTPUT_PATH']
-	archive_out = conf['OUTPUT_PATH']
-	out_ext = conf['OUTPUT_EXT']
-	count = conf['COUNT']
-	queue = conf['QUEUE']
-	print_log = conf['LOG']
-	warn = conf['WARN']
-	no_write = conf['NO_WRITE']
-	dedupe = conf['DEDUPE']
-	table = conf['TABLE']
-	dedupe = conf['DEDUPE']
-	from_archive = True if conf['IS_FULL_TEXT']==True else False
-
-	completion_time = time.time()
-	elapsed = completion_time - start_time
-	cases_per_sec = count/elapsed
-
-	if print_log:
+def complete(conf, *outputs):
+	if not conf.DEBUG:
+		sys.tracebacklimit = 0
+		warnings.filterwarnings('ignore')
+	if conf.LOG and len(outputs)>0:
+		click.echo(outputs)
+	if conf.LOG:
 		click.secho(f'''\n* Task completed!\n''',bold=True,fg='green')
 
 def debug(conf, *msg):
